export interface OpenBody {
    method: string;
    url: string | URL;
    async: boolean;
    username?: string | null;
    password?: string | null;
}
export interface GlobalXmlContext {
    openContent?: OpenBody;
    sendContent?: SendBody;
    responseContext?: ResponseBody;
}
export declare type ResponseBody = XMLHttpRequest['response'];
export declare type SendBody = Document | XMLHttpRequestBodyInit | null | undefined;
export declare type BeforeXmlOpen = (body: OpenBody, context: GlobalXmlContext) => OpenBody;
export declare type AfterXmlOpen = (body: OpenBody, context: GlobalXmlContext) => void;
export declare type BeforeXmlSend = (body: SendBody, context: GlobalXmlContext) => SendBody;
export declare type AfterXmlSend = (body: SendBody, context: GlobalXmlContext) => void;
export declare type BeforeXmlResponse = (context: GlobalXmlContext) => ResponseBody;
export declare type AfterXmlResponese = (body: ResponseBody, context: GlobalXmlContext) => void;
export interface XMLHttpHooks {
    beforeXmlOpen?: BeforeXmlOpen;
    afterXmlOpen?: AfterXmlOpen;
    beforeXmlSend?: BeforeXmlSend;
    afterXmlSend?: AfterXmlSend;
    beforeXmlResponse?: BeforeXmlResponse;
    afterXmlResponese?: AfterXmlResponese;
}
export interface XMLHttpRequestParameter extends XMLHttpHooks {
    originXML: typeof window.XMLHttpRequest;
}
/**
 * xml hooks
 * @param XMLHttpRequestParameter
 * @returns xml
 */
export declare const xmlHttpReauestHook: ({ originXML, beforeXmlOpen, afterXmlOpen, beforeXmlSend, afterXmlSend, beforeXmlResponse, afterXmlResponese, }: XMLHttpRequestParameter) => {
    new (): {
        globalContext: GlobalXmlContext;
        open(method: string, url: string | URL, async?: boolean, username?: string | null | undefined, password?: string | null | undefined): void;
        send(originBody?: Document | XMLHttpRequestBodyInit | null | undefined): void;
        onreadystatechange: ((this: XMLHttpRequest, ev: Event) => any) | null;
        readonly readyState: number;
        readonly response: any;
        readonly responseText: string;
        responseType: XMLHttpRequestResponseType;
        readonly responseURL: string;
        readonly responseXML: Document | null;
        readonly status: number;
        readonly statusText: string;
        timeout: number;
        readonly upload: XMLHttpRequestUpload;
        withCredentials: boolean;
        abort(): void;
        getAllResponseHeaders(): string;
        getResponseHeader(name: string): string | null;
        overrideMimeType(mime: string): void;
        setRequestHeader(name: string, value: string): void;
        readonly DONE: number;
        readonly HEADERS_RECEIVED: number;
        readonly LOADING: number;
        readonly OPENED: number;
        readonly UNSENT: number;
        addEventListener<K extends keyof XMLHttpRequestEventMap>(type: K, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions | undefined): void;
        addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions | undefined): void;
        removeEventListener<K_1 extends keyof XMLHttpRequestEventMap>(type: K_1, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K_1]) => any, options?: boolean | EventListenerOptions | undefined): void;
        removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions | undefined): void;
        onabort: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        onerror: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        onload: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        onloadend: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        onloadstart: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        onprogress: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        ontimeout: ((this: XMLHttpRequest, ev: ProgressEvent<EventTarget>) => any) | null;
        dispatchEvent(event: Event): boolean;
    };
    readonly DONE: number;
    readonly HEADERS_RECEIVED: number;
    readonly LOADING: number;
    readonly OPENED: number;
    readonly UNSENT: number;
};
